aboutsummaryrefslogtreecommitdiff
path: root/build/scope.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'build/scope.cxx')
-rw-r--r--build/scope.cxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/build/scope.cxx b/build/scope.cxx
index 60c83b4..f907163 100644
--- a/build/scope.cxx
+++ b/build/scope.cxx
@@ -33,7 +33,7 @@ namespace build
// scope_map
//
scope_map scopes;
- scope* root_scope;
+ scope* global_scope;
pair<scope&, bool> scope_map::
insert (const path& k)
@@ -46,7 +46,7 @@ namespace build
scope* p (nullptr);
// Update scopes of which we are a new parent (unless this is the
- // root scope).
+ // global scope).
//
if (size () > 1)
{
@@ -102,7 +102,7 @@ namespace build
if (i != end ())
return i->second;
- assert (!d.empty ()); // We should have the root scope.
+ assert (!d.empty ()); // We should have the global scope.
}
}
}